@@ -1,5 +1,12 @@
 #' Tube efficiency
 #'
+#' Computation is consistent with the approach described in Hogue, Mark;
+#' Thompson, Martha; Farfan, Eduardo; Hadlock, Dennis, (2014),
+#' "Hand Calculations for Transport of Radioactive Aerosols through
+#' Sampling Systems" Health Phys 106, 5, S78-S87,
+#' <doi:10.1097/HP.0000000000000092>, with the exception that the diffusion
+#' deposition mechanism is included.
+#'
 #' In order to run this function, first produce a particle distribution
 #' with the `particle_dist` function, then produce a parameter set with
 #' the `set_params` function. Both of these results must be stored as
@@ -9,7 +16,7 @@
 #' `particle_dist` function
 #' @param params is the parameter data set for parameters that are not
 #' particle size-dependent
-#' @param L tube length, m
+#' @param L_cm tube length, cm
 #' @param angle_to_horiz angle to horizontal in degrees
 #' @param elnum element number to provide unique column names
 #'
@@ -17,21 +24,48 @@
 #' data for this element
 #'
 #' @examples
+#' # Example output is a sample of the full particle data set.
+#'
+#' # laminar flow (Reynolds number < 2100)
+#'
+#' df <- particle_dist() #  distribution
+#' params <- set_params_1("D_tube" = 2.54, "Q_lpm" = 20,
+#' "T_C" = 25, "P_kPa" = 101.325) #example system parameters
+#' df <- set_params_2(df, params) #particle size-dependent parameters
+#' df <- probe_eff(df, params, orient = 'h') #probe orientation - horizontal
+#' df <- tube_eff(df, params, L_cm = 100,
+#' angle_to_horiz = 90, elnum = 2)
+#' (df[sort(sample(1:1000, 10)), ])
+
+#' # turbulent flow (Reynolds number > 4000)
+#'
 #' df <- particle_dist() #  distribution
 #' params <- set_params_1("D_tube" = 2.54, "Q_lpm" = 100,
 #' "T_C" = 25, "P_kPa" = 101.325) #example system parameters
 #' df <- set_params_2(df, params) #particle size-dependent parameters
 #' df <- probe_eff(df, params, orient = 'h') #probe orientation - horizontal
-#' df <- tube_eff(df, params, L = 100,
+#' df <- tube_eff(df, params, L_cm = 100,
 #' angle_to_horiz = 90, elnum = 2)
-#' head(df)
+#' (df[sort(sample(1:1000, 10)), ])
+#'
+#' # midrange flow (Reynolds number > 2100 and < 4000)
+#'
+#' df <- particle_dist() #  distribution
+#' params <- set_params_1("D_tube" = 2.54, "Q_lpm" = 60,
+#' "T_C" = 25, "P_kPa" = 101.325) #example system parameters
+#' df <- set_params_2(df, params) #particle size-dependent parameters
+#' df <- probe_eff(df, params, orient = 'h') #probe orientation - horizontal
+#' df <- tube_eff(df, params, L_cm = 100,
+#' angle_to_horiz = 90, elnum = 2)
+#' (df[sort(sample(1:1000, 10)), ])
 #'
 #' @export
 #'
-tube_eff <- function(df, params, L, angle_to_horiz, elnum) {
+tube_eff <- function(df, params, L_cm, angle_to_horiz, elnum) {
     # convert angle from degrees to radians
     angle_to_horiz_radians <- angle_to_horiz * pi/180
 
+    L <- L_cm / 100 # L is in meters
 # assign some factors for use as needed:
 
     # diffusion coefficient
@@ -90,7 +124,12 @@ tube_eff <- function(df, params, L, angle_to_horiz, elnum) {
     turb <- eff_turb * eff_therm * eff_grav_turb
 
     # in between, use lower of the two
-    mixed <- min(c(lam, turb))
+    lam_min <- lam < turb
+    mixed <- dplyr::case_when(
+      lam_min == TRUE ~ lam,
+      TRUE ~ turb
+    )
+
 
   eff_tube <- dplyr::case_when(
     # laminar flow
